# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_compute.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#azure/azure_microsoft_compute.proto\x12#oak9.tython.azure.microsoft_compute\x1a\x13shared/shared.proto\"\xde\x04\n\x11Microsoft_Compute\x12P\n\x11\x61vailability_sets\x18\x01 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_compute.AvailabilitySets\x12\x63\n\x1b\x63\x61pacity_reservation_groups\x18\x02 \x03(\x0b\x32>.oak9.tython.azure.microsoft_compute.CapacityReservationGroups\x12\x44\n\x0bhost_groups\x18\x03 \x03(\x0b\x32/.oak9.tython.azure.microsoft_compute.HostGroups\x12;\n\x06images\x18\x04 \x03(\x0b\x32+.oak9.tython.azure.microsoft_compute.Images\x12\x61\n\x1aproximity_placement_groups\x18\x05 \x03(\x0b\x32=.oak9.tython.azure.microsoft_compute.ProximityPlacementGroups\x12_\n\x19restore_point_collections\x18\x06 \x03(\x0b\x32<.oak9.tython.azure.microsoft_compute.RestorePointCollections\x12K\n\x0fssh_public_keys\x18\x07 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_compute.SshPublicKeys\"\xf5\x01\n\rSshPublicKeys\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\npublic_key\x18\x04 \x01(\t\x12J\n\x04tags\x18\x05 \x03(\x0b\x32<.oak9.tython.azure.microsoft_compute.SshPublicKeys.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaa\x02\n$RestorePointCollectionsRestorePoints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12N\n\rexclude_disks\x18\x03 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_compute.ApiEntityReference\x12U\n\x14source_restore_point\x18\x04 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_compute.ApiEntityReference\x12\x14\n\x0ctime_created\x18\x05 \x01(\t\" \n\x12\x41piEntityReference\x12\n\n\x02id\x18\x01 \x01(\t\"\xcf\x03\n\x17RestorePointCollections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12[\n\x06source\x18\x04 \x01(\x0b\x32K.oak9.tython.azure.microsoft_compute.RestorePointCollectionSourceProperties\x12T\n\x04tags\x18\x05 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_compute.RestorePointCollections.TagsEntry\x12{\n(restore_point_collections_restore_points\x18\x06 \x03(\x0b\x32I.oak9.tython.azure.microsoft_compute.RestorePointCollectionsRestorePoints\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n&RestorePointCollectionSourceProperties\x12\n\n\x02id\x18\x01 \x01(\t\"\xf3\x02\n\x18ProximityPlacementGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12R\n\x11\x63olocation_status\x18\x04 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_compute.InstanceViewStatus\x12&\n\x1eproximity_placement_group_type\x18\x05 \x01(\t\x12U\n\x04tags\x18\x06 \x03(\x0b\x32G.oak9.tython.azure.microsoft_compute.ProximityPlacementGroups.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x12InstanceViewStatus\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x16\n\x0e\x64isplay_status\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x0c\n\x04time\x18\x05 \x01(\t\"\xb4\x03\n\x06Images\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x11\x65xtended_location\x18\x02 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_compute.ExtendedLocation\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1a\n\x12hyper_v_generation\x18\x05 \x01(\t\x12\x1e\n\x16source_virtual_machine\x18\x06 \x01(\t\x12Q\n\x0fstorage_profile\x18\x07 \x01(\x0b\x32\x38.oak9.tython.azure.microsoft_compute.ImageStorageProfile\x12\x43\n\x04tags\x18\x08 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_compute.Images.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb8\x01\n\x13ImageStorageProfile\x12\x46\n\ndata_disks\x18\x01 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_compute.ImageDataDisk\x12\x41\n\x07os_disk\x18\x02 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_compute.ImageOSDisk\x12\x16\n\x0ezone_resilient\x18\x03 \x01(\x08\"\x8e\x02\n\x0bImageOSDisk\x12\x10\n\x08\x62lob_uri\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61\x63hing\x18\x02 \x01(\t\x12]\n\x13\x64isk_encryption_set\x18\x03 \x01(\x0b\x32@.oak9.tython.azure.microsoft_compute.DiskEncryptionSetParameters\x12\x14\n\x0c\x64isk_size_gb\x18\x04 \x01(\x05\x12\x14\n\x0cmanaged_disk\x18\x05 \x01(\t\x12\x10\n\x08os_state\x18\x06 \x01(\t\x12\x0f\n\x07os_type\x18\x07 \x01(\t\x12\x10\n\x08snapshot\x18\x08 \x01(\t\x12\x1c\n\x14storage_account_type\x18\t \x01(\t\"\xfa\x01\n\rImageDataDisk\x12\x10\n\x08\x62lob_uri\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61\x63hing\x18\x02 \x01(\t\x12]\n\x13\x64isk_encryption_set\x18\x03 \x01(\x0b\x32@.oak9.tython.azure.microsoft_compute.DiskEncryptionSetParameters\x12\x14\n\x0c\x64isk_size_gb\x18\x04 \x01(\x05\x12\x0b\n\x03lun\x18\x05 \x01(\x05\x12\x14\n\x0cmanaged_disk\x18\x06 \x01(\t\x12\x10\n\x08snapshot\x18\x07 \x01(\t\x12\x1c\n\x14storage_account_type\x18\x08 \x01(\t\")\n\x1b\x44iskEncryptionSetParameters\x12\n\n\x02id\x18\x01 \x01(\t\".\n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\xf2\x02\n\x0fHostGroupsHosts\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1f\n\x17\x61uto_replace_on_failure\x18\x04 \x01(\x08\x12\x14\n\x0clicense_type\x18\x05 \x01(\t\x12\x1d\n\x15platform_fault_domain\x18\x06 \x01(\x05\x12\x35\n\x03sku\x18\x07 \x01(\x0b\x32(.oak9.tython.azure.microsoft_compute.Sku\x12L\n\x04tags\x18\x08 \x03(\x0b\x32>.oak9.tython.azure.microsoft_compute.HostGroupsHosts.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x85\x03\n\nHostGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12#\n\x1bplatform_fault_domain_count\x18\x04 \x01(\x05\x12#\n\x1bsupport_automatic_placement\x18\x05 \x01(\x08\x12G\n\x04tags\x18\x06 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_compute.HostGroups.TagsEntry\x12\r\n\x05zones\x18\x07 \x03(\t\x12O\n\x11host_groups_hosts\x18\x08 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_compute.HostGroupsHosts\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe7\x02\n-CapacityReservationGroupsCapacityReservations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x35\n\x03sku\x18\x04 \x01(\x0b\x32(.oak9.tython.azure.microsoft_compute.Sku\x12j\n\x04tags\x18\x05 \x03(\x0b\x32\\.oak9.tython.azure.microsoft_compute.CapacityReservationGroupsCapacityReservations.TagsEntry\x12\r\n\x05zones\x18\x06 \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x03\n\x19\x43\x61pacityReservationGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12V\n\x04tags\x18\x04 \x03(\x0b\x32H.oak9.tython.azure.microsoft_compute.CapacityReservationGroups.TagsEntry\x12\r\n\x05zones\x18\x05 \x03(\t\x12\x8d\x01\n1capacity_reservation_groups_capacity_reservations\x18\x06 \x03(\x0b\x32R.oak9.tython.azure.microsoft_compute.CapacityReservationGroupsCapacityReservations\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa6\x03\n\x10\x41vailabilitySets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12#\n\x1bplatform_fault_domain_count\x18\x04 \x01(\x05\x12$\n\x1cplatform_update_domain_count\x18\x05 \x01(\x05\x12!\n\x19proximity_placement_group\x18\x06 \x01(\t\x12\x18\n\x10virtual_machines\x18\x07 \x03(\t\x12\x35\n\x03sku\x18\x08 \x01(\x0b\x32(.oak9.tython.azure.microsoft_compute.Sku\x12M\n\x04tags\x18\t \x03(\x0b\x32?.oak9.tython.azure.microsoft_compute.AvailabilitySets.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x03Sku\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04tier\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_compute_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SSHPUBLICKEYS_TAGSENTRY._options = None
  _SSHPUBLICKEYS_TAGSENTRY._serialized_options = b'8\001'
  _RESTOREPOINTCOLLECTIONS_TAGSENTRY._options = None
  _RESTOREPOINTCOLLECTIONS_TAGSENTRY._serialized_options = b'8\001'
  _PROXIMITYPLACEMENTGROUPS_TAGSENTRY._options = None
  _PROXIMITYPLACEMENTGROUPS_TAGSENTRY._serialized_options = b'8\001'
  _IMAGES_TAGSENTRY._options = None
  _IMAGES_TAGSENTRY._serialized_options = b'8\001'
  _HOSTGROUPSHOSTS_TAGSENTRY._options = None
  _HOSTGROUPSHOSTS_TAGSENTRY._serialized_options = b'8\001'
  _HOSTGROUPS_TAGSENTRY._options = None
  _HOSTGROUPS_TAGSENTRY._serialized_options = b'8\001'
  _CAPACITYRESERVATIONGROUPSCAPACITYRESERVATIONS_TAGSENTRY._options = None
  _CAPACITYRESERVATIONGROUPSCAPACITYRESERVATIONS_TAGSENTRY._serialized_options = b'8\001'
  _CAPACITYRESERVATIONGROUPS_TAGSENTRY._options = None
  _CAPACITYRESERVATIONGROUPS_TAGSENTRY._serialized_options = b'8\001'
  _AVAILABILITYSETS_TAGSENTRY._options = None
  _AVAILABILITYSETS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_COMPUTE._serialized_start=98
  _MICROSOFT_COMPUTE._serialized_end=704
  _SSHPUBLICKEYS._serialized_start=707
  _SSHPUBLICKEYS._serialized_end=952
  _SSHPUBLICKEYS_TAGSENTRY._serialized_start=909
  _SSHPUBLICKEYS_TAGSENTRY._serialized_end=952
  _RESTOREPOINTCOLLECTIONSRESTOREPOINTS._serialized_start=955
  _RESTOREPOINTCOLLECTIONSRESTOREPOINTS._serialized_end=1253
  _APIENTITYREFERENCE._serialized_start=1255
  _APIENTITYREFERENCE._serialized_end=1287
  _RESTOREPOINTCOLLECTIONS._serialized_start=1290
  _RESTOREPOINTCOLLECTIONS._serialized_end=1753
  _RESTOREPOINTCOLLECTIONS_TAGSENTRY._serialized_start=909
  _RESTOREPOINTCOLLECTIONS_TAGSENTRY._serialized_end=952
  _RESTOREPOINTCOLLECTIONSOURCEPROPERTIES._serialized_start=1755
  _RESTOREPOINTCOLLECTIONSOURCEPROPERTIES._serialized_end=1807
  _PROXIMITYPLACEMENTGROUPS._serialized_start=1810
  _PROXIMITYPLACEMENTGROUPS._serialized_end=2181
  _PROXIMITYPLACEMENTGROUPS_TAGSENTRY._serialized_start=909
  _PROXIMITYPLACEMENTGROUPS_TAGSENTRY._serialized_end=952
  _INSTANCEVIEWSTATUS._serialized_start=2183
  _INSTANCEVIEWSTATUS._serialized_end=2287
  _IMAGES._serialized_start=2290
  _IMAGES._serialized_end=2726
  _IMAGES_TAGSENTRY._serialized_start=909
  _IMAGES_TAGSENTRY._serialized_end=952
  _IMAGESTORAGEPROFILE._serialized_start=2729
  _IMAGESTORAGEPROFILE._serialized_end=2913
  _IMAGEOSDISK._serialized_start=2916
  _IMAGEOSDISK._serialized_end=3186
  _IMAGEDATADISK._serialized_start=3189
  _IMAGEDATADISK._serialized_end=3439
  _DISKENCRYPTIONSETPARAMETERS._serialized_start=3441
  _DISKENCRYPTIONSETPARAMETERS._serialized_end=3482
  _EXTENDEDLOCATION._serialized_start=3484
  _EXTENDEDLOCATION._serialized_end=3530
  _HOSTGROUPSHOSTS._serialized_start=3533
  _HOSTGROUPSHOSTS._serialized_end=3903
  _HOSTGROUPSHOSTS_TAGSENTRY._serialized_start=909
  _HOSTGROUPSHOSTS_TAGSENTRY._serialized_end=952
  _HOSTGROUPS._serialized_start=3906
  _HOSTGROUPS._serialized_end=4295
  _HOSTGROUPS_TAGSENTRY._serialized_start=909
  _HOSTGROUPS_TAGSENTRY._serialized_end=952
  _CAPACITYRESERVATIONGROUPSCAPACITYRESERVATIONS._serialized_start=4298
  _CAPACITYRESERVATIONGROUPSCAPACITYRESERVATIONS._serialized_end=4657
  _CAPACITYRESERVATIONGROUPSCAPACITYRESERVATIONS_TAGSENTRY._serialized_start=909
  _CAPACITYRESERVATIONGROUPSCAPACITYRESERVATIONS_TAGSENTRY._serialized_end=952
  _CAPACITYRESERVATIONGROUPS._serialized_start=4660
  _CAPACITYRESERVATIONGROUPS._serialized_end=5068
  _CAPACITYRESERVATIONGROUPS_TAGSENTRY._serialized_start=909
  _CAPACITYRESERVATIONGROUPS_TAGSENTRY._serialized_end=952
  _AVAILABILITYSETS._serialized_start=5071
  _AVAILABILITYSETS._serialized_end=5493
  _AVAILABILITYSETS_TAGSENTRY._serialized_start=909
  _AVAILABILITYSETS_TAGSENTRY._serialized_end=952
  _SKU._serialized_start=5495
  _SKU._serialized_end=5546
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GkeHubMembershipXAuthority(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISSUER_FIELD_NUMBER: builtins.int
    issuer: builtins.str
    def __init__(
        self,
        *,
        issuer: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["issuer", b"issuer"]) -> None: ...

global___GkeHubMembershipXAuthority = GkeHubMembershipXAuthority

@typing_extensions.final
class GkeHubMembershipXEndpointXGkeCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_LINK_FIELD_NUMBER: builtins.int
    resource_link: builtins.str
    def __init__(
        self,
        *,
        resource_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_link", b"resource_link"]) -> None: ...

global___GkeHubMembershipXEndpointXGkeCluster = GkeHubMembershipXEndpointXGkeCluster

@typing_extensions.final
class GkeHubMembershipXEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GKE_CLUSTER_FIELD_NUMBER: builtins.int
    @property
    def gke_cluster(self) -> global___GkeHubMembershipXEndpointXGkeCluster: ...
    def __init__(
        self,
        *,
        gke_cluster: global___GkeHubMembershipXEndpointXGkeCluster | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gke_cluster", b"gke_cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gke_cluster", b"gke_cluster"]) -> None: ...

global___GkeHubMembershipXEndpoint = GkeHubMembershipXEndpoint

@typing_extensions.final
class GkeHubMembershipXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___GkeHubMembershipXTimeouts = GkeHubMembershipXTimeouts

@typing_extensions.final
class GkeHubMembership(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MEMBERSHIP_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    AUTHORITY_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    membership_id: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def authority(self) -> global___GkeHubMembershipXAuthority: ...
    @property
    def endpoint(self) -> global___GkeHubMembershipXEndpoint: ...
    @property
    def timeouts(self) -> global___GkeHubMembershipXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        membership_id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        authority: global___GkeHubMembershipXAuthority | None = ...,
        endpoint: global___GkeHubMembershipXEndpoint | None = ...,
        timeouts: global___GkeHubMembershipXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authority", b"authority", "endpoint", b"endpoint", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authority", b"authority", "endpoint", b"endpoint", "id", b"id", "labels", b"labels", "membership_id", b"membership_id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___GkeHubMembership = GkeHubMembership



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codedeploy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_codedeploy.proto\x12\x1aoak9.tython.aws.codedeploy\x1a\x13shared/shared.proto\"z\n\x0b\x41pplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x18\n\x10\x63ompute_platform\x18\x03 \x01(\t\"\xda\x01\n\nCodeDeploy\x12<\n\x0b\x61pplication\x18\x01 \x03(\x0b\x32\'.oak9.tython.aws.codedeploy.Application\x12G\n\x11\x64\x65ployment_config\x18\x02 \x03(\x0b\x32,.oak9.tython.aws.codedeploy.DeploymentConfig\x12\x45\n\x10\x64\x65ployment_group\x18\x03 \x03(\x0b\x32+.oak9.tython.aws.codedeploy.DeploymentGroup\"m\n#DeploymentConfigMinimumHealthyHosts\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\x05\"\xcb\x01\n\x10\x44\x65ploymentConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x64\x65ployment_config_name\x18\x02 \x01(\t\x12^\n\x15minimum_healthy_hosts\x18\x03 \x01(\x0b\x32?.oak9.tython.aws.codedeploy.DeploymentConfigMinimumHealthyHosts\"]\n\x14\x44\x65ploymentGroupAlarm\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd2\x01\n!DeploymentGroupAlarmConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12@\n\x06\x61larms\x18\x02 \x03(\x0b\x32\x30.oak9.tython.aws.codedeploy.DeploymentGroupAlarm\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12!\n\x19ignore_poll_alarm_failure\x18\x04 \x01(\x08\"\x84\x01\n(DeploymentGroupAutoRollbackConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x0e\n\x06\x65vents\x18\x03 \x03(\t\"\x7f\n\x1d\x44\x65ploymentGroupGitHubLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tcommit_id\x18\x02 \x01(\t\x12\x12\n\nrepository\x18\x03 \x01(\t\"\xa6\x01\n\x19\x44\x65ploymentGroupS3Location\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x13\n\x0b\x62undle_type\x18\x03 \x01(\t\x12\r\n\x05\x65_tag\x18\x04 \x01(\t\x12\x0b\n\x03key\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t\"\x92\x02\n\x1f\x44\x65ploymentGroupRevisionLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x10git_hub_location\x18\x02 \x01(\x0b\x32\x39.oak9.tython.aws.codedeploy.DeploymentGroupGitHubLocation\x12\x15\n\rrevision_type\x18\x03 \x01(\t\x12J\n\x0bs3_location\x18\x04 \x01(\x0b\x32\x35.oak9.tython.aws.codedeploy.DeploymentGroupS3Location\"\xe2\x01\n\x19\x44\x65ploymentGroupDeployment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12(\n ignore_application_stop_failures\x18\x03 \x01(\x08\x12M\n\x08revision\x18\x04 \x01(\x0b\x32;.oak9.tython.aws.codedeploy.DeploymentGroupRevisionLocation\"\x8d\x01\n\x1e\x44\x65ploymentGroupDeploymentStyle\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x64\x65ployment_option\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65ployment_type\x18\x03 \x01(\t\"r\n\x1b\x44\x65ploymentGroupEC2TagFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xad\x01\n\"DeploymentGroupEC2TagSetListObject\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12N\n\rec2_tag_group\x18\x02 \x03(\x0b\x32\x37.oak9.tython.aws.codedeploy.DeploymentGroupEC2TagFilter\"\xad\x01\n\x18\x44\x65ploymentGroupEC2TagSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\x10\x65\x63\x32_tag_set_list\x18\x02 \x03(\x0b\x32>.oak9.tython.aws.codedeploy.DeploymentGroupEC2TagSetListObject\"_\n\x16\x44\x65ploymentGroupELBInfo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"g\n\x1e\x44\x65ploymentGroupTargetGroupInfo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x81\x02\n\x1f\x44\x65ploymentGroupLoadBalancerInfo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12I\n\relb_info_list\x18\x02 \x03(\x0b\x32\x32.oak9.tython.aws.codedeploy.DeploymentGroupELBInfo\x12Z\n\x16target_group_info_list\x18\x03 \x03(\x0b\x32:.oak9.tython.aws.codedeploy.DeploymentGroupTargetGroupInfo\"o\n\x18\x44\x65ploymentGroupTagFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xb9\x01\n)DeploymentGroupOnPremisesTagSetListObject\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x15on_premises_tag_group\x18\x02 \x03(\x0b\x32\x34.oak9.tython.aws.codedeploy.DeploymentGroupTagFilter\"\xc3\x01\n\x1f\x44\x65ploymentGroupOnPremisesTagSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12g\n\x18on_premises_tag_set_list\x18\x02 \x03(\x0b\x32\x45.oak9.tython.aws.codedeploy.DeploymentGroupOnPremisesTagSetListObject\"\xa1\x01\n\x1c\x44\x65ploymentGroupTriggerConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0etrigger_events\x18\x02 \x03(\t\x12\x14\n\x0ctrigger_name\x18\x03 \x01(\t\x12\x1a\n\x12trigger_target_arn\x18\x04 \x01(\t\"\xcc\x08\n\x0f\x44\x65ploymentGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x13\x61larm_configuration\x18\x02 \x01(\x0b\x32=.oak9.tython.aws.codedeploy.DeploymentGroupAlarmConfiguration\x12\x18\n\x10\x61pplication_name\x18\x03 \x01(\t\x12i\n\x1b\x61uto_rollback_configuration\x18\x04 \x01(\x0b\x32\x44.oak9.tython.aws.codedeploy.DeploymentGroupAutoRollbackConfiguration\x12\x1b\n\x13\x61uto_scaling_groups\x18\x05 \x03(\t\x12I\n\ndeployment\x18\x06 \x01(\x0b\x32\x35.oak9.tython.aws.codedeploy.DeploymentGroupDeployment\x12\x1e\n\x16\x64\x65ployment_config_name\x18\x07 \x01(\t\x12\x1d\n\x15\x64\x65ployment_group_name\x18\x08 \x01(\t\x12T\n\x10\x64\x65ployment_style\x18\t \x01(\x0b\x32:.oak9.tython.aws.codedeploy.DeploymentGroupDeploymentStyle\x12P\n\x0f\x65\x63\x32_tag_filters\x18\n \x03(\x0b\x32\x37.oak9.tython.aws.codedeploy.DeploymentGroupEC2TagFilter\x12I\n\x0b\x65\x63\x32_tag_set\x18\x0b \x01(\x0b\x32\x34.oak9.tython.aws.codedeploy.DeploymentGroupEC2TagSet\x12W\n\x12load_balancer_info\x18\x0c \x01(\x0b\x32;.oak9.tython.aws.codedeploy.DeploymentGroupLoadBalancerInfo\x12^\n on_premises_instance_tag_filters\x18\r \x03(\x0b\x32\x34.oak9.tython.aws.codedeploy.DeploymentGroupTagFilter\x12X\n\x13on_premises_tag_set\x18\x0e \x01(\x0b\x32;.oak9.tython.aws.codedeploy.DeploymentGroupOnPremisesTagSet\x12\x18\n\x10service_role_arn\x18\x0f \x01(\t\x12X\n\x16trigger_configurations\x18\x10 \x03(\x0b\x32\x38.oak9.tython.aws.codedeploy.DeploymentGroupTriggerConfigb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codedeploy_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APPLICATION._serialized_start=77
  _APPLICATION._serialized_end=199
  _CODEDEPLOY._serialized_start=202
  _CODEDEPLOY._serialized_end=420
  _DEPLOYMENTCONFIGMINIMUMHEALTHYHOSTS._serialized_start=422
  _DEPLOYMENTCONFIGMINIMUMHEALTHYHOSTS._serialized_end=531
  _DEPLOYMENTCONFIG._serialized_start=534
  _DEPLOYMENTCONFIG._serialized_end=737
  _DEPLOYMENTGROUPALARM._serialized_start=739
  _DEPLOYMENTGROUPALARM._serialized_end=832
  _DEPLOYMENTGROUPALARMCONFIGURATION._serialized_start=835
  _DEPLOYMENTGROUPALARMCONFIGURATION._serialized_end=1045
  _DEPLOYMENTGROUPAUTOROLLBACKCONFIGURATION._serialized_start=1048
  _DEPLOYMENTGROUPAUTOROLLBACKCONFIGURATION._serialized_end=1180
  _DEPLOYMENTGROUPGITHUBLOCATION._serialized_start=1182
  _DEPLOYMENTGROUPGITHUBLOCATION._serialized_end=1309
  _DEPLOYMENTGROUPS3LOCATION._serialized_start=1312
  _DEPLOYMENTGROUPS3LOCATION._serialized_end=1478
  _DEPLOYMENTGROUPREVISIONLOCATION._serialized_start=1481
  _DEPLOYMENTGROUPREVISIONLOCATION._serialized_end=1755
  _DEPLOYMENTGROUPDEPLOYMENT._serialized_start=1758
  _DEPLOYMENTGROUPDEPLOYMENT._serialized_end=1984
  _DEPLOYMENTGROUPDEPLOYMENTSTYLE._serialized_start=1987
  _DEPLOYMENTGROUPDEPLOYMENTSTYLE._serialized_end=2128
  _DEPLOYMENTGROUPEC2TAGFILTER._serialized_start=2130
  _DEPLOYMENTGROUPEC2TAGFILTER._serialized_end=2244
  _DEPLOYMENTGROUPEC2TAGSETLISTOBJECT._serialized_start=2247
  _DEPLOYMENTGROUPEC2TAGSETLISTOBJECT._serialized_end=2420
  _DEPLOYMENTGROUPEC2TAGSET._serialized_start=2423
  _DEPLOYMENTGROUPEC2TAGSET._serialized_end=2596
  _DEPLOYMENTGROUPELBINFO._serialized_start=2598
  _DEPLOYMENTGROUPELBINFO._serialized_end=2693
  _DEPLOYMENTGROUPTARGETGROUPINFO._serialized_start=2695
  _DEPLOYMENTGROUPTARGETGROUPINFO._serialized_end=2798
  _DEPLOYMENTGROUPLOADBALANCERINFO._serialized_start=2801
  _DEPLOYMENTGROUPLOADBALANCERINFO._serialized_end=3058
  _DEPLOYMENTGROUPTAGFILTER._serialized_start=3060
  _DEPLOYMENTGROUPTAGFILTER._serialized_end=3171
  _DEPLOYMENTGROUPONPREMISESTAGSETLISTOBJECT._serialized_start=3174
  _DEPLOYMENTGROUPONPREMISESTAGSETLISTOBJECT._serialized_end=3359
  _DEPLOYMENTGROUPONPREMISESTAGSET._serialized_start=3362
  _DEPLOYMENTGROUPONPREMISESTAGSET._serialized_end=3557
  _DEPLOYMENTGROUPTRIGGERCONFIG._serialized_start=3560
  _DEPLOYMENTGROUPTRIGGERCONFIG._serialized_end=3721
  _DEPLOYMENTGROUP._serialized_start=3724
  _DEPLOYMENTGROUP._serialized_end=4824
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_servicecatalog.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61ws/aws_servicecatalog.proto\x12\x1eoak9.tython.aws.servicecatalog\x1a\x13shared/shared.proto\"\x80\x01\n\x16\x41\x63\x63\x65ptedPortfolioShare\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x02 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x03 \x01(\t\"\xe3\t\n\x0eServiceCatalog\x12X\n\x18\x61\x63\x63\x65pted_portfolio_share\x18\x01 \x03(\x0b\x32\x36.oak9.tython.aws.servicecatalog.AcceptedPortfolioShare\x12V\n\x17\x63loud_formation_product\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.servicecatalog.CloudFormationProduct\x12m\n#cloud_formation_provisioned_product\x18\x03 \x03(\x0b\x32@.oak9.tython.aws.servicecatalog.CloudFormationProvisionedProduct\x12\x64\n\x1elaunch_notification_constraint\x18\x04 \x03(\x0b\x32<.oak9.tython.aws.servicecatalog.LaunchNotificationConstraint\x12T\n\x16launch_role_constraint\x18\x05 \x03(\x0b\x32\x34.oak9.tython.aws.servicecatalog.LaunchRoleConstraint\x12\\\n\x1alaunch_template_constraint\x18\x06 \x03(\x0b\x32\x38.oak9.tython.aws.servicecatalog.LaunchTemplateConstraint\x12<\n\tportfolio\x18\x07 \x03(\x0b\x32).oak9.tython.aws.servicecatalog.Portfolio\x12\x66\n\x1fportfolio_principal_association\x18\x08 \x03(\x0b\x32=.oak9.tython.aws.servicecatalog.PortfolioPrincipalAssociation\x12\x62\n\x1dportfolio_product_association\x18\t \x03(\x0b\x32;.oak9.tython.aws.servicecatalog.PortfolioProductAssociation\x12G\n\x0fportfolio_share\x18\n \x03(\x0b\x32..oak9.tython.aws.servicecatalog.PortfolioShare\x12\\\n\x1aresource_update_constraint\x18\x0b \x03(\x0b\x32\x38.oak9.tython.aws.servicecatalog.ResourceUpdateConstraint\x12P\n\x14stack_set_constraint\x18\x0c \x03(\x0b\x32\x32.oak9.tython.aws.servicecatalog.StackSetConstraint\x12=\n\ntag_option\x18\r \x03(\x0b\x32).oak9.tython.aws.servicecatalog.TagOption\x12T\n\x16tag_option_association\x18\x0e \x03(\x0b\x32\x34.oak9.tython.aws.servicecatalog.TagOptionAssociation\"\xd0\x02\n3CloudFormationProductProvisioningArtifactProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12#\n\x1b\x64isable_template_validation\x18\x03 \x01(\x08\x12k\n\x04info\x18\x04 \x03(\x0b\x32].oak9.tython.aws.servicecatalog.CloudFormationProductProvisioningArtifactProperties.InfoEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x1a+\n\tInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x04\n\x15\x43loudFormationProduct\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1ereplace_provisioning_artifacts\x18\x02 \x01(\x08\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x1b\n\x13support_description\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x13\n\x0b\x64istributor\x18\x06 \x01(\t\x12\x15\n\rsupport_email\x18\x07 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x08 \x01(\t\x12\x13\n\x0bsupport_url\x18\t \x01(\t\x12M\n\x04tags\x18\n \x03(\x0b\x32?.oak9.tython.aws.servicecatalog.CloudFormationProduct.TagsEntry\x12\x0c\n\x04name\x18\x0b \x01(\t\x12}\n provisioning_artifact_parameters\x18\x0c \x03(\x0b\x32S.oak9.tython.aws.servicecatalog.CloudFormationProductProvisioningArtifactProperties\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n5CloudFormationProvisionedProductProvisioningParameter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xfd\x02\n7CloudFormationProvisionedProductProvisioningPreferences\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12stack_set_accounts\x18\x02 \x03(\t\x12)\n!stack_set_failure_tolerance_count\x18\x03 \x01(\x05\x12.\n&stack_set_failure_tolerance_percentage\x18\x04 \x01(\x05\x12\'\n\x1fstack_set_max_concurrency_count\x18\x05 \x01(\x05\x12,\n$stack_set_max_concurrency_percentage\x18\x06 \x01(\x05\x12 \n\x18stack_set_operation_type\x18\x07 \x01(\t\x12\x19\n\x11stack_set_regions\x18\x08 \x03(\t\"\xbf\x05\n CloudFormationProvisionedProduct\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x02 \x01(\t\x12\x19\n\x11notification_arns\x18\x03 \x03(\t\x12\x0f\n\x07path_id\x18\x04 \x01(\t\x12\x11\n\tpath_name\x18\x05 \x01(\t\x12\x12\n\nproduct_id\x18\x06 \x01(\t\x12\x14\n\x0cproduct_name\x18\x07 \x01(\t\x12 \n\x18provisioned_product_name\x18\x08 \x01(\t\x12 \n\x18provisioning_artifact_id\x18\t \x01(\t\x12\"\n\x1aprovisioning_artifact_name\x18\n \x01(\t\x12v\n\x17provisioning_parameters\x18\x0b \x03(\x0b\x32U.oak9.tython.aws.servicecatalog.CloudFormationProvisionedProductProvisioningParameter\x12y\n\x18provisioning_preferences\x18\x0c \x01(\x0b\x32W.oak9.tython.aws.servicecatalog.CloudFormationProvisionedProductProvisioningPreferences\x12X\n\x04tags\x18\r \x03(\x0b\x32J.oak9.tython.aws.servicecatalog.CloudFormationProvisionedProduct.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xca\x01\n\x1cLaunchNotificationConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x19\n\x11notification_arns\x18\x03 \x03(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x04 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x05 \x01(\t\x12\x12\n\nproduct_id\x18\x06 \x01(\t\"\xd2\x01\n\x14LaunchRoleConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x17\n\x0flocal_role_name\x18\x03 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x04 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x05 \x01(\t\x12\x12\n\nproduct_id\x18\x06 \x01(\t\x12\x10\n\x08role_arn\x18\x07 \x01(\t\"\xba\x01\n\x18LaunchTemplateConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x03 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x04 \x01(\t\x12\x12\n\nproduct_id\x18\x05 \x01(\t\x12\r\n\x05rules\x18\x06 \x01(\t\"\x8f\x02\n\tPortfolio\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rprovider_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x05 \x01(\t\x12\x41\n\x04tags\x18\x06 \x03(\x0b\x32\x33.oak9.tython.aws.servicecatalog.Portfolio.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x01\n\x1dPortfolioPrincipalAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rprincipal_arn\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x03 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x04 \x01(\t\x12\x16\n\x0eprincipal_type\x18\x05 \x01(\t\"\xb6\x01\n\x1bPortfolioProductAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13source_portfolio_id\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x03 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x04 \x01(\t\x12\x12\n\nproduct_id\x18\x05 \x01(\t\"\x8c\x01\n\x0ePortfolioShare\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\naccount_id\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x03 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x04 \x01(\t\"\xd6\x01\n\x18ResourceUpdateConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x03 \x01(\t\x12)\n!tag_update_on_provisioned_product\x18\x04 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x05 \x01(\t\x12\x12\n\nproduct_id\x18\x06 \x01(\t\"\x9c\x02\n\x12StackSetConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1e\n\x16stack_instance_control\x18\x03 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65pt_language\x18\x04 \x01(\t\x12\x14\n\x0cportfolio_id\x18\x05 \x01(\t\x12\x12\n\nproduct_id\x18\x06 \x01(\t\x12\x13\n\x0bregion_list\x18\x07 \x03(\t\x12\x12\n\nadmin_role\x18\x08 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_list\x18\t \x03(\t\x12\x16\n\x0e\x65xecution_role\x18\n \x01(\t\"p\n\tTagOption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\r\n\x05value\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\"{\n\x14TagOptionAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rtag_option_id\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_servicecatalog_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLOUDFORMATIONPRODUCTPROVISIONINGARTIFACTPROPERTIES_INFOENTRY._options = None
  _CLOUDFORMATIONPRODUCTPROVISIONINGARTIFACTPROPERTIES_INFOENTRY._serialized_options = b'8\001'
  _CLOUDFORMATIONPRODUCT_TAGSENTRY._options = None
  _CLOUDFORMATIONPRODUCT_TAGSENTRY._serialized_options = b'8\001'
  _CLOUDFORMATIONPROVISIONEDPRODUCT_TAGSENTRY._options = None
  _CLOUDFORMATIONPROVISIONEDPRODUCT_TAGSENTRY._serialized_options = b'8\001'
  _PORTFOLIO_TAGSENTRY._options = None
  _PORTFOLIO_TAGSENTRY._serialized_options = b'8\001'
  _ACCEPTEDPORTFOLIOSHARE._serialized_start=86
  _ACCEPTEDPORTFOLIOSHARE._serialized_end=214
  _SERVICECATALOG._serialized_start=217
  _SERVICECATALOG._serialized_end=1468
  _CLOUDFORMATIONPRODUCTPROVISIONINGARTIFACTPROPERTIES._serialized_start=1471
  _CLOUDFORMATIONPRODUCTPROVISIONINGARTIFACTPROPERTIES._serialized_end=1807
  _CLOUDFORMATIONPRODUCTPROVISIONINGARTIFACTPROPERTIES_INFOENTRY._serialized_start=1764
  _CLOUDFORMATIONPRODUCTPROVISIONINGARTIFACTPROPERTIES_INFOENTRY._serialized_end=1807
  _CLOUDFORMATIONPRODUCT._serialized_start=1810
  _CLOUDFORMATIONPRODUCT._serialized_end=2350
  _CLOUDFORMATIONPRODUCT_TAGSENTRY._serialized_start=2307
  _CLOUDFORMATIONPRODUCT_TAGSENTRY._serialized_end=2350
  _CLOUDFORMATIONPROVISIONEDPRODUCTPROVISIONINGPARAMETER._serialized_start=2353
  _CLOUDFORMATIONPROVISIONEDPRODUCTPROVISIONINGPARAMETER._serialized_end=2493
  _CLOUDFORMATIONPROVISIONEDPRODUCTPROVISIONINGPREFERENCES._serialized_start=2496
  _CLOUDFORMATIONPROVISIONEDPRODUCTPROVISIONINGPREFERENCES._serialized_end=2877
  _CLOUDFORMATIONPROVISIONEDPRODUCT._serialized_start=2880
  _CLOUDFORMATIONPROVISIONEDPRODUCT._serialized_end=3583
  _CLOUDFORMATIONPROVISIONEDPRODUCT_TAGSENTRY._serialized_start=2307
  _CLOUDFORMATIONPROVISIONEDPRODUCT_TAGSENTRY._serialized_end=2350
  _LAUNCHNOTIFICATIONCONSTRAINT._serialized_start=3586
  _LAUNCHNOTIFICATIONCONSTRAINT._serialized_end=3788
  _LAUNCHROLECONSTRAINT._serialized_start=3791
  _LAUNCHROLECONSTRAINT._serialized_end=4001
  _LAUNCHTEMPLATECONSTRAINT._serialized_start=4004
  _LAUNCHTEMPLATECONSTRAINT._serialized_end=4190
  _PORTFOLIO._serialized_start=4193
  _PORTFOLIO._serialized_end=4464
  _PORTFOLIO_TAGSENTRY._serialized_start=2307
  _PORTFOLIO_TAGSENTRY._serialized_end=2350
  _PORTFOLIOPRINCIPALASSOCIATION._serialized_start=4467
  _PORTFOLIOPRINCIPALASSOCIATION._serialized_end=4649
  _PORTFOLIOPRODUCTASSOCIATION._serialized_start=4652
  _PORTFOLIOPRODUCTASSOCIATION._serialized_end=4834
  _PORTFOLIOSHARE._serialized_start=4837
  _PORTFOLIOSHARE._serialized_end=4977
  _RESOURCEUPDATECONSTRAINT._serialized_start=4980
  _RESOURCEUPDATECONSTRAINT._serialized_end=5194
  _STACKSETCONSTRAINT._serialized_start=5197
  _STACKSETCONSTRAINT._serialized_end=5481
  _TAGOPTION._serialized_start=5483
  _TAGOPTION._serialized_end=5595
  _TAGOPTIONASSOCIATION._serialized_start=5597
  _TAGOPTIONASSOCIATION._serialized_end=5720
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ClusterEBSStorageInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VOLUME_SIZE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    volume_size: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        volume_size: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "volume_size", b"volume_size"]) -> None: ...

global___ClusterEBSStorageInfo = ClusterEBSStorageInfo

@typing_extensions.final
class ClusterStorageInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EBS_STORAGE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def ebs_storage_info(self) -> global___ClusterEBSStorageInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ebs_storage_info: global___ClusterEBSStorageInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ebs_storage_info", b"ebs_storage_info", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ebs_storage_info", b"ebs_storage_info", "resource_info", b"resource_info"]) -> None: ...

global___ClusterStorageInfo = ClusterStorageInfo

@typing_extensions.final
class ClusterBrokerNodeGroupInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    CLIENT_SUBNETS_FIELD_NUMBER: builtins.int
    STORAGE_INFO_FIELD_NUMBER: builtins.int
    BROKER_AZ_DISTRIBUTION_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def client_subnets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def storage_info(self) -> global___ClusterStorageInfo: ...
    broker_az_distribution: builtins.str
    instance_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        client_subnets: collections.abc.Iterable[builtins.str] | None = ...,
        storage_info: global___ClusterStorageInfo | None = ...,
        broker_az_distribution: builtins.str = ...,
        instance_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "storage_info", b"storage_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["broker_az_distribution", b"broker_az_distribution", "client_subnets", b"client_subnets", "instance_type", b"instance_type", "resource_info", b"resource_info", "security_groups", b"security_groups", "storage_info", b"storage_info"]) -> None: ...

global___ClusterBrokerNodeGroupInfo = ClusterBrokerNodeGroupInfo

@typing_extensions.final
class ClusterEncryptionAtRest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DATA_VOLUME_KMS_KEY_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    data_volume_kms_key_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        data_volume_kms_key_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_volume_kms_key_id", b"data_volume_kms_key_id", "resource_info", b"resource_info"]) -> None: ...

global___ClusterEncryptionAtRest = ClusterEncryptionAtRest

@typing_extensions.final
class ClusterEncryptionInTransit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLIENT_BROKER_FIELD_NUMBER: builtins.int
    IN_CLUSTER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    client_broker: builtins.str
    in_cluster: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        client_broker: builtins.str = ...,
        in_cluster: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_broker", b"client_broker", "in_cluster", b"in_cluster", "resource_info", b"resource_info"]) -> None: ...

global___ClusterEncryptionInTransit = ClusterEncryptionInTransit

@typing_extensions.final
class ClusterEncryptionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENCRYPTION_AT_REST_FIELD_NUMBER: builtins.int
    ENCRYPTION_IN_TRANSIT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def encryption_at_rest(self) -> global___ClusterEncryptionAtRest: ...
    @property
    def encryption_in_transit(self) -> global___ClusterEncryptionInTransit: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        encryption_at_rest: global___ClusterEncryptionAtRest | None = ...,
        encryption_in_transit: global___ClusterEncryptionInTransit | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["encryption_at_rest", b"encryption_at_rest", "encryption_in_transit", b"encryption_in_transit", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encryption_at_rest", b"encryption_at_rest", "encryption_in_transit", b"encryption_in_transit", "resource_info", b"resource_info"]) -> None: ...

global___ClusterEncryptionInfo = ClusterEncryptionInfo

@typing_extensions.final
class ClusterJmxExporter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_IN_BROKER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled_in_broker: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled_in_broker: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled_in_broker", b"enabled_in_broker", "resource_info", b"resource_info"]) -> None: ...

global___ClusterJmxExporter = ClusterJmxExporter

@typing_extensions.final
class ClusterNodeExporter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_IN_BROKER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled_in_broker: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled_in_broker: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled_in_broker", b"enabled_in_broker", "resource_info", b"resource_info"]) -> None: ...

global___ClusterNodeExporter = ClusterNodeExporter

@typing_extensions.final
class ClusterPrometheus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    JMX_EXPORTER_FIELD_NUMBER: builtins.int
    NODE_EXPORTER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def jmx_exporter(self) -> global___ClusterJmxExporter: ...
    @property
    def node_exporter(self) -> global___ClusterNodeExporter: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        jmx_exporter: global___ClusterJmxExporter | None = ...,
        node_exporter: global___ClusterNodeExporter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["jmx_exporter", b"jmx_exporter", "node_exporter", b"node_exporter", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["jmx_exporter", b"jmx_exporter", "node_exporter", b"node_exporter", "resource_info", b"resource_info"]) -> None: ...

global___ClusterPrometheus = ClusterPrometheus

@typing_extensions.final
class ClusterOpenMonitoring(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PROMETHEUS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def prometheus(self) -> global___ClusterPrometheus: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        prometheus: global___ClusterPrometheus | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["prometheus", b"prometheus", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["prometheus", b"prometheus", "resource_info", b"resource_info"]) -> None: ...

global___ClusterOpenMonitoring = ClusterOpenMonitoring

@typing_extensions.final
class ClusterScram(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "resource_info", b"resource_info"]) -> None: ...

global___ClusterScram = ClusterScram

@typing_extensions.final
class ClusterSasl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SCRAM_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def scram(self) -> global___ClusterScram: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        scram: global___ClusterScram | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "scram", b"scram"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "scram", b"scram"]) -> None: ...

global___ClusterSasl = ClusterSasl

@typing_extensions.final
class ClusterTls(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CERTIFICATE_AUTHORITY_ARN_LIST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def certificate_authority_arn_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        certificate_authority_arn_list: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_authority_arn_list", b"certificate_authority_arn_list", "resource_info", b"resource_info"]) -> None: ...

global___ClusterTls = ClusterTls

@typing_extensions.final
class ClusterClientAuthentication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SASL_FIELD_NUMBER: builtins.int
    TLS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def sasl(self) -> global___ClusterSasl: ...
    @property
    def tls(self) -> global___ClusterTls: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        sasl: global___ClusterSasl | None = ...,
        tls: global___ClusterTls | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sasl", b"sasl", "tls", b"tls"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sasl", b"sasl", "tls", b"tls"]) -> None: ...

global___ClusterClientAuthentication = ClusterClientAuthentication

@typing_extensions.final
class ClusterS3(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bucket: builtins.str
    enabled: builtins.bool
    prefix: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bucket: builtins.str = ...,
        enabled: builtins.bool = ...,
        prefix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "enabled", b"enabled", "prefix", b"prefix", "resource_info", b"resource_info"]) -> None: ...

global___ClusterS3 = ClusterS3

@typing_extensions.final
class ClusterFirehose(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DELIVERY_STREAM_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    delivery_stream: builtins.str
    enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        delivery_stream: builtins.str = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_stream", b"delivery_stream", "enabled", b"enabled", "resource_info", b"resource_info"]) -> None: ...

global___ClusterFirehose = ClusterFirehose

@typing_extensions.final
class ClusterCloudWatchLogs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOG_GROUP_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    log_group: builtins.str
    enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        log_group: builtins.str = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "log_group", b"log_group", "resource_info", b"resource_info"]) -> None: ...

global___ClusterCloudWatchLogs = ClusterCloudWatchLogs

@typing_extensions.final
class ClusterBrokerLogs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_FIELD_NUMBER: builtins.int
    FIREHOSE_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def s3(self) -> global___ClusterS3: ...
    @property
    def firehose(self) -> global___ClusterFirehose: ...
    @property
    def cloud_watch_logs(self) -> global___ClusterCloudWatchLogs: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3: global___ClusterS3 | None = ...,
        firehose: global___ClusterFirehose | None = ...,
        cloud_watch_logs: global___ClusterCloudWatchLogs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_watch_logs", b"cloud_watch_logs", "firehose", b"firehose", "resource_info", b"resource_info", "s3", b"s3"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_watch_logs", b"cloud_watch_logs", "firehose", b"firehose", "resource_info", b"resource_info", "s3", b"s3"]) -> None: ...

global___ClusterBrokerLogs = ClusterBrokerLogs

@typing_extensions.final
class ClusterLoggingInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BROKER_LOGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def broker_logs(self) -> global___ClusterBrokerLogs: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        broker_logs: global___ClusterBrokerLogs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["broker_logs", b"broker_logs", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["broker_logs", b"broker_logs", "resource_info", b"resource_info"]) -> None: ...

global___ClusterLoggingInfo = ClusterLoggingInfo

@typing_extensions.final
class ClusterConfigurationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    revision: builtins.int
    arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        revision: builtins.int = ...,
        arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arn", b"arn", "resource_info", b"resource_info", "revision", b"revision"]) -> None: ...

global___ClusterConfigurationInfo = ClusterConfigurationInfo

@typing_extensions.final
class Cluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BROKER_NODE_GROUP_INFO_FIELD_NUMBER: builtins.int
    ENHANCED_MONITORING_FIELD_NUMBER: builtins.int
    KAFKA_VERSION_FIELD_NUMBER: builtins.int
    NUMBER_OF_BROKER_NODES_FIELD_NUMBER: builtins.int
    ENCRYPTION_INFO_FIELD_NUMBER: builtins.int
    OPEN_MONITORING_FIELD_NUMBER: builtins.int
    CLUSTER_NAME_FIELD_NUMBER: builtins.int
    CLIENT_AUTHENTICATION_FIELD_NUMBER: builtins.int
    LOGGING_INFO_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    CONFIGURATION_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def broker_node_group_info(self) -> global___ClusterBrokerNodeGroupInfo: ...
    enhanced_monitoring: builtins.str
    kafka_version: builtins.str
    number_of_broker_nodes: builtins.int
    @property
    def encryption_info(self) -> global___ClusterEncryptionInfo: ...
    @property
    def open_monitoring(self) -> global___ClusterOpenMonitoring: ...
    cluster_name: builtins.str
    @property
    def client_authentication(self) -> global___ClusterClientAuthentication: ...
    @property
    def logging_info(self) -> global___ClusterLoggingInfo: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def configuration_info(self) -> global___ClusterConfigurationInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        broker_node_group_info: global___ClusterBrokerNodeGroupInfo | None = ...,
        enhanced_monitoring: builtins.str = ...,
        kafka_version: builtins.str = ...,
        number_of_broker_nodes: builtins.int = ...,
        encryption_info: global___ClusterEncryptionInfo | None = ...,
        open_monitoring: global___ClusterOpenMonitoring | None = ...,
        cluster_name: builtins.str = ...,
        client_authentication: global___ClusterClientAuthentication | None = ...,
        logging_info: global___ClusterLoggingInfo | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        configuration_info: global___ClusterConfigurationInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["broker_node_group_info", b"broker_node_group_info", "client_authentication", b"client_authentication", "configuration_info", b"configuration_info", "encryption_info", b"encryption_info", "logging_info", b"logging_info", "open_monitoring", b"open_monitoring", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["broker_node_group_info", b"broker_node_group_info", "client_authentication", b"client_authentication", "cluster_name", b"cluster_name", "configuration_info", b"configuration_info", "encryption_info", b"encryption_info", "enhanced_monitoring", b"enhanced_monitoring", "kafka_version", b"kafka_version", "logging_info", b"logging_info", "number_of_broker_nodes", b"number_of_broker_nodes", "open_monitoring", b"open_monitoring", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Cluster = Cluster

@typing_extensions.final
class MSK(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    @property
    def cluster(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Cluster]: ...
    def __init__(
        self,
        *,
        cluster: collections.abc.Iterable[global___Cluster] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster"]) -> None: ...

global___MSK = MSK



from oak9.sac_framework.core.types import Severity, Violation
from oak9.sac_framework.core.exception import ViolationException
from oak9.sac_framework.core.tools import get_config_id


class AzureAks():
    oak9_base = 'Oak9.Containers.ContainerManagement.Application'
    blueprint_type = 'AzureAks'
    sn = 'aks'

    def check_logging_aks(aks, context):

        violations = []

        try:
            pass

        except Exception as e:
            violations.append(ViolationException(e))

        return violations

    def check_transparent_data_encryption_aks(aks, context):
        """
        Temp disks and cache for agent node pools in Azure Kubernetes Service clusters should be encrypted at host.

        To enhance data security, the data stored on the virtual machine (VM) host of your Azure Kubernetes Service
        nodes VMs should be encrypted at rest. This is a common requirement in many regulatory and industry compliance
        standards.

        Implements:
            AZURE_POLICY: https://github.com/Azure/azure-policy/blob/master/built-in-policies/policyDefinitions/Kubernetes/AKS_EncryptionAtHost_Deny.json
        Coverage:
            Partial:
                TODO (atcherniakhovski): Validate that this handles the case of multiple node-pools.
        """
        violations = []

        try:

            if aks.managed_clusters.disk_encryption_set_id == "":
                violations.append(
                    Violation(
                        severity=Severity.Critical,
                        config_id=get_config_id(aks, 'disk_encryption_set_id'),
                        resource_id=aks.managed_clusters.resource_info.id,
                        resource_type=aks.managed_clusters.resource_into.resource_type,
                        config_value=aks.managed_clusters.disk_encryption_set_id
                    )
                )

        except Exception as e:
            violations.append(ViolationException(e))

        return violations




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_alexa_ask.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_alexa_ask.proto\x12\x19oak9.tython.aws.alexa_ask\x1a\x13shared/shared.proto\"\xa7\x01\n+Alexa_ASK_Skill_AuthenticationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x15\n\rclient_secret\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\"\xdb\x01\n\x19\x41lexa_ASK_Skill_Overrides\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12T\n\x08manifest\x18\x02 \x03(\x0b\x32\x42.oak9.tython.aws.alexa_ask.Alexa_ASK_Skill_Overrides.ManifestEntry\x1a/\n\rManifestEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf6\x01\n\x1c\x41lexa_ASK_Skill_SkillPackage\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0es3_bucket_role\x18\x02 \x01(\t\x12\x19\n\x11s3_object_version\x18\x03 \x01(\t\x12\x11\n\ts3_bucket\x18\x04 \x01(\t\x12\x0e\n\x06s3_key\x18\x05 \x01(\t\x12G\n\toverrides\x18\x06 \x01(\x0b\x32\x34.oak9.tython.aws.alexa_ask.Alexa_ASK_Skill_Overrides\"\x9b\x02\n\x0f\x41lexa_ASK_Skill\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12l\n\x1c\x61uthentication_configuration\x18\x02 \x01(\x0b\x32\x46.oak9.tython.aws.alexa_ask.Alexa_ASK_Skill_AuthenticationConfiguration\x12\x11\n\tvendor_id\x18\x03 \x01(\t\x12N\n\rskill_package\x18\x04 \x01(\x0b\x32\x37.oak9.tython.aws.alexa_ask.Alexa_ASK_Skill_SkillPackage\"T\n\tAlexa_ASK\x12G\n\x13\x61lexa__a_s_k__skill\x18\x01 \x03(\x0b\x32*.oak9.tython.aws.alexa_ask.Alexa_ASK_Skillb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_alexa_ask_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ALEXA_ASK_SKILL_OVERRIDES_MANIFESTENTRY._options = None
  _ALEXA_ASK_SKILL_OVERRIDES_MANIFESTENTRY._serialized_options = b'8\001'
  _ALEXA_ASK_SKILL_AUTHENTICATIONCONFIGURATION._serialized_start=76
  _ALEXA_ASK_SKILL_AUTHENTICATIONCONFIGURATION._serialized_end=243
  _ALEXA_ASK_SKILL_OVERRIDES._serialized_start=246
  _ALEXA_ASK_SKILL_OVERRIDES._serialized_end=465
  _ALEXA_ASK_SKILL_OVERRIDES_MANIFESTENTRY._serialized_start=418
  _ALEXA_ASK_SKILL_OVERRIDES_MANIFESTENTRY._serialized_end=465
  _ALEXA_ASK_SKILL_SKILLPACKAGE._serialized_start=468
  _ALEXA_ASK_SKILL_SKILLPACKAGE._serialized_end=714
  _ALEXA_ASK_SKILL._serialized_start=717
  _ALEXA_ASK_SKILL._serialized_end=1000
  _ALEXA_ASK._serialized_start=1002
  _ALEXA_ASK._serialized_end=1086
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_storage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gcp/gcp_storage.proto\x12\x17oak9.tython.gcp.storage\x1a\x13shared/shared.proto\"f\n\x12StorageBucketXCors\x12\x17\n\x0fmax_age_seconds\x18\x01 \x01(\x01\x12\x0e\n\x06method\x18\x02 \x03(\t\x12\x0e\n\x06origin\x18\x03 \x03(\t\x12\x17\n\x0fresponse_header\x18\x04 \x03(\t\"8\n\x18StorageBucketXEncryption\x12\x1c\n\x14\x64\x65\x66\x61ult_kms_key_name\x18\x01 \x01(\t\"I\n\"StorageBucketXLifecycleRuleXAction\x12\x15\n\rstorage_class\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\xcb\x02\n%StorageBucketXLifecycleRuleXCondition\x12\x0b\n\x03\x61ge\x18\x01 \x01(\x01\x12\x16\n\x0e\x63reated_before\x18\x02 \x01(\t\x12\x1a\n\x12\x63ustom_time_before\x18\x03 \x01(\t\x12\x1e\n\x16\x64\x61ys_since_custom_time\x18\x04 \x01(\x01\x12\"\n\x1a\x64\x61ys_since_noncurrent_time\x18\x05 \x01(\x01\x12\x16\n\x0ematches_prefix\x18\x06 \x03(\t\x12\x1d\n\x15matches_storage_class\x18\x07 \x03(\t\x12\x16\n\x0ematches_suffix\x18\x08 \x03(\t\x12\x1e\n\x16noncurrent_time_before\x18\t \x01(\t\x12\x1a\n\x12num_newer_versions\x18\n \x01(\x01\x12\x12\n\nwith_state\x18\x0b \x01(\t\"\xbd\x01\n\x1bStorageBucketXLifecycleRule\x12K\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32;.oak9.tython.gcp.storage.StorageBucketXLifecycleRuleXAction\x12Q\n\tcondition\x18\x02 \x01(\x0b\x32>.oak9.tython.gcp.storage.StorageBucketXLifecycleRuleXCondition\"F\n\x15StorageBucketXLogging\x12\x12\n\nlog_bucket\x18\x01 \x01(\t\x12\x19\n\x11log_object_prefix\x18\x02 \x01(\t\"L\n\x1dStorageBucketXRetentionPolicy\x12\x11\n\tis_locked\x18\x01 \x01(\x08\x12\x18\n\x10retention_period\x18\x02 \x01(\x01\"F\n\x16StorageBucketXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0c\n\x04read\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"+\n\x18StorageBucketXVersioning\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"I\n\x15StorageBucketXWebsite\x12\x18\n\x10main_page_suffix\x18\x01 \x01(\t\x12\x16\n\x0enot_found_page\x18\x02 \x01(\t\"\xd3\x07\n\rStorageBucket\x12 \n\x18\x64\x65\x66\x61ult_event_based_hold\x18\x01 \x01(\x08\x12\x15\n\rforce_destroy\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x42\n\x06labels\x18\x04 \x03(\x0b\x32\x32.oak9.tython.gcp.storage.StorageBucket.LabelsEntry\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x16\n\x0erequester_pays\x18\x08 \x01(\x08\x12\x11\n\tself_link\x18\t \x01(\t\x12\x15\n\rstorage_class\x18\n \x01(\t\x12#\n\x1buniform_bucket_level_access\x18\x0b \x01(\x08\x12\x0b\n\x03url\x18\x0c \x01(\t\x12\x39\n\x04\x63ors\x18\r \x03(\x0b\x32+.oak9.tython.gcp.storage.StorageBucketXCors\x12\x45\n\nencryption\x18\x0e \x01(\x0b\x32\x31.oak9.tython.gcp.storage.StorageBucketXEncryption\x12L\n\x0elifecycle_rule\x18\x0f \x03(\x0b\x32\x34.oak9.tython.gcp.storage.StorageBucketXLifecycleRule\x12?\n\x07logging\x18\x10 \x01(\x0b\x32..oak9.tython.gcp.storage.StorageBucketXLogging\x12P\n\x10retention_policy\x18\x11 \x01(\x0b\x32\x36.oak9.tython.gcp.storage.StorageBucketXRetentionPolicy\x12\x41\n\x08timeouts\x18\x12 \x01(\x0b\x32/.oak9.tython.gcp.storage.StorageBucketXTimeouts\x12\x45\n\nversioning\x18\x13 \x01(\x0b\x32\x31.oak9.tython.gcp.storage.StorageBucketXVersioning\x12?\n\x07website\x18\x14 \x01(\x0b\x32..oak9.tython.gcp.storage.StorageBucketXWebsite\x12\x37\n\rresource_info\x18\x15 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n#StorageBucketAccessControlXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xfe\x01\n\x1aStorageBucketAccessControl\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06\x65ntity\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12N\n\x08timeouts\x18\x07 \x01(\x0b\x32<.oak9.tython.gcp.storage.StorageBucketAccessControlXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa9\x01\n\x10StorageBucketAcl\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65\x66\x61ult_acl\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x16\n\x0epredefined_acl\x18\x04 \x01(\t\x12\x13\n\x0brole_entity\x18\x05 \x03(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"[\n!StorageBucketIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xea\x01\n\x17StorageBucketIamBinding\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12M\n\tcondition\x18\x06 \x01(\x0b\x32:.oak9.tython.gcp.storage.StorageBucketIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Z\n StorageBucketIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xe7\x01\n\x16StorageBucketIamMember\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12L\n\tcondition\x18\x06 \x01(\x0b\x32\x39.oak9.tython.gcp.storage.StorageBucketIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x90\x01\n\x16StorageBucketIamPolicy\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"^\n&StorageBucketObjectXCustomerEncryption\x12\x1c\n\x14\x65ncryption_algorithm\x18\x01 \x01(\t\x12\x16\n\x0e\x65ncryption_key\x18\x02 \x01(\t\"N\n\x1cStorageBucketObjectXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x91\x06\n\x13StorageBucketObject\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x15\n\rcache_control\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x1b\n\x13\x63ontent_disposition\x18\x04 \x01(\t\x12\x18\n\x10\x63ontent_encoding\x18\x05 \x01(\t\x12\x18\n\x10\x63ontent_language\x18\x06 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x07 \x01(\t\x12\x0e\n\x06\x63rc32c\x18\x08 \x01(\t\x12\x16\n\x0e\x64\x65tect_md5hash\x18\t \x01(\t\x12\x18\n\x10\x65vent_based_hold\x18\n \x01(\x08\x12\n\n\x02id\x18\x0b \x01(\t\x12\x14\n\x0ckms_key_name\x18\x0c \x01(\t\x12\x0f\n\x07md5hash\x18\r \x01(\t\x12\x12\n\nmedia_link\x18\x0e \x01(\t\x12L\n\x08metadata\x18\x0f \x03(\x0b\x32:.oak9.tython.gcp.storage.StorageBucketObject.MetadataEntry\x12\x0c\n\x04name\x18\x10 \x01(\t\x12\x13\n\x0boutput_name\x18\x11 \x01(\t\x12\x11\n\tself_link\x18\x12 \x01(\t\x12\x0e\n\x06source\x18\x13 \x01(\t\x12\x15\n\rstorage_class\x18\x14 \x01(\t\x12\x16\n\x0etemporary_hold\x18\x15 \x01(\x08\x12\\\n\x13\x63ustomer_encryption\x18\x16 \x01(\x0b\x32?.oak9.tython.gcp.storage.StorageBucketObjectXCustomerEncryption\x12G\n\x08timeouts\x18\x17 \x01(\x0b\x32\x35.oak9.tython.gcp.storage.StorageBucketObjectXTimeouts\x12\x37\n\rresource_info\x18\x18 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\\\n*StorageDefaultObjectAccessControlXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xda\x03\n!StorageDefaultObjectAccessControl\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06\x65ntity\x18\x04 \x01(\t\x12\x11\n\tentity_id\x18\x05 \x01(\t\x12\x12\n\ngeneration\x18\x06 \x01(\x01\x12\n\n\x02id\x18\x07 \x01(\t\x12\x0e\n\x06object\x18\x08 \x01(\t\x12\x61\n\x0cproject_team\x18\t \x03(\x0b\x32K.oak9.tython.gcp.storage.StorageDefaultObjectAccessControl.ProjectTeamEntry\x12\x0c\n\x04role\x18\n \x01(\t\x12U\n\x08timeouts\x18\x0b \x01(\x0b\x32\x43.oak9.tython.gcp.storage.StorageDefaultObjectAccessControlXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10ProjectTeamEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x01\n\x17StorageDefaultObjectAcl\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0brole_entity\x18\x03 \x03(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"I\n\x17StorageHmacKeyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa2\x02\n\x0eStorageHmacKey\x12\x11\n\taccess_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x0e\n\x06secret\x18\x04 \x01(\t\x12\x1d\n\x15service_account_email\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\x14\n\x0ctime_created\x18\x07 \x01(\t\x12\x0f\n\x07updated\x18\x08 \x01(\t\x12\x42\n\x08timeouts\x18\t \x01(\x0b\x32\x30.oak9.tython.gcp.storage.StorageHmacKeyXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x86\x03\n\x13StorageNotification\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12]\n\x11\x63ustom_attributes\x18\x02 \x03(\x0b\x32\x42.oak9.tython.gcp.storage.StorageNotification.CustomAttributesEntry\x12\x13\n\x0b\x65vent_types\x18\x03 \x03(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x17\n\x0fnotification_id\x18\x05 \x01(\t\x12\x1a\n\x12object_name_prefix\x18\x06 \x01(\t\x12\x16\n\x0epayload_format\x18\x07 \x01(\t\x12\x11\n\tself_link\x18\x08 \x01(\t\x12\r\n\x05topic\x18\t \x01(\t\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x37\n\x15\x43ustomAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n#StorageObjectAccessControlXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc5\x03\n\x1aStorageObjectAccessControl\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06\x65ntity\x18\x04 \x01(\t\x12\x11\n\tentity_id\x18\x05 \x01(\t\x12\x12\n\ngeneration\x18\x06 \x01(\x01\x12\n\n\x02id\x18\x07 \x01(\t\x12\x0e\n\x06object\x18\x08 \x01(\t\x12Z\n\x0cproject_team\x18\t \x03(\x0b\x32\x44.oak9.tython.gcp.storage.StorageObjectAccessControl.ProjectTeamEntry\x12\x0c\n\x04role\x18\n \x01(\t\x12N\n\x08timeouts\x18\x0b \x01(\x0b\x32<.oak9.tython.gcp.storage.StorageObjectAccessControlXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10ProjectTeamEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa4\x01\n\x10StorageObjectAcl\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06object\x18\x03 \x01(\t\x12\x16\n\x0epredefined_acl\x18\x04 \x01(\t\x12\x13\n\x0brole_entity\x18\x05 \x03(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n+StorageTransferJobXScheduleXScheduleEndDate\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\x01\x12\r\n\x05month\x18\x02 \x01(\x01\x12\x0c\n\x04year\x18\x03 \x01(\x01\"Y\n-StorageTransferJobXScheduleXScheduleStartDate\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\x01\x12\r\n\x05month\x18\x02 \x01(\x01\x12\x0c\n\x04year\x18\x03 \x01(\x01\"l\n*StorageTransferJobXScheduleXStartTimeOfDay\x12\r\n\x05hours\x18\x01 \x01(\x01\x12\x0f\n\x07minutes\x18\x02 \x01(\x01\x12\r\n\x05nanos\x18\x03 \x01(\x01\x12\x0f\n\x07seconds\x18\x04 \x01(\x01\"\xdc\x02\n\x1bStorageTransferJobXSchedule\x12\x17\n\x0frepeat_interval\x18\x01 \x01(\t\x12_\n\x11schedule_end_date\x18\x02 \x01(\x0b\x32\x44.oak9.tython.gcp.storage.StorageTransferJobXScheduleXScheduleEndDate\x12\x63\n\x13schedule_start_date\x18\x03 \x01(\x0b\x32\x46.oak9.tython.gcp.storage.StorageTransferJobXScheduleXScheduleStartDate\x12^\n\x11start_time_of_day\x18\x04 \x01(\x0b\x32\x43.oak9.tython.gcp.storage.StorageTransferJobXScheduleXStartTimeOfDay\"p\n<StorageTransferJobXTransferSpecXAwsS3DataSourceXAwsAccessKey\x12\x15\n\raccess_key_id\x18\x01 \x01(\t\x12\x19\n\x11secret_access_key\x18\x02 \x01(\t\"\xc7\x01\n/StorageTransferJobXTransferSpecXAwsS3DataSource\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x10\n\x08role_arn\x18\x02 \x01(\t\x12m\n\x0e\x61ws_access_key\x18\x03 \x01(\x0b\x32U.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXAwsS3DataSourceXAwsAccessKey\"`\nKStorageTransferJobXTransferSpecXAzureBlobStorageDataSourceXAzureCredentials\x12\x11\n\tsas_token\x18\x01 \x01(\t\"\xf7\x01\n:StorageTransferJobXTransferSpecXAzureBlobStorageDataSource\x12\x11\n\tcontainer\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x17\n\x0fstorage_account\x18\x03 \x01(\t\x12\x7f\n\x11\x61zure_credentials\x18\x04 \x01(\x0b\x32\x64.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXAzureBlobStorageDataSourceXAzureCredentials\"P\n+StorageTransferJobXTransferSpecXGcsDataSink\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"R\n-StorageTransferJobXTransferSpecXGcsDataSource\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"B\n.StorageTransferJobXTransferSpecXHttpDataSource\x12\x10\n\x08list_url\x18\x01 \x01(\t\"\xca\x01\n0StorageTransferJobXTransferSpecXObjectConditions\x12\x18\n\x10\x65xclude_prefixes\x18\x01 \x03(\t\x12\x18\n\x10include_prefixes\x18\x02 \x03(\t\x12\x30\n(max_time_elapsed_since_last_modification\x18\x03 \x01(\t\x12\x30\n(min_time_elapsed_since_last_modification\x18\x04 \x01(\t\"G\n-StorageTransferJobXTransferSpecXPosixDataSink\x12\x16\n\x0eroot_directory\x18\x01 \x01(\t\"I\n/StorageTransferJobXTransferSpecXPosixDataSource\x12\x16\n\x0eroot_directory\x18\x01 \x01(\t\"\xbf\x01\n/StorageTransferJobXTransferSpecXTransferOptions\x12\x31\n)delete_objects_from_source_after_transfer\x18\x01 \x01(\x08\x12%\n\x1d\x64\x65lete_objects_unique_in_sink\x18\x02 \x01(\x08\x12\x32\n*overwrite_objects_already_existing_in_sink\x18\x03 \x01(\x08\"\xb5\x07\n\x1fStorageTransferJobXTransferSpec\x12\x64\n\x12\x61ws_s3_data_source\x18\x01 \x01(\x0b\x32H.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXAwsS3DataSource\x12{\n\x1e\x61zure_blob_storage_data_source\x18\x02 \x01(\x0b\x32S.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXAzureBlobStorageDataSource\x12[\n\rgcs_data_sink\x18\x03 \x01(\x0b\x32\x44.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXGcsDataSink\x12_\n\x0fgcs_data_source\x18\x04 \x01(\x0b\x32\x46.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXGcsDataSource\x12\x61\n\x10http_data_source\x18\x05 \x01(\x0b\x32G.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXHttpDataSource\x12\x64\n\x11object_conditions\x18\x06 \x01(\x0b\x32I.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXObjectConditions\x12_\n\x0fposix_data_sink\x18\x07 \x01(\x0b\x32\x46.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXPosixDataSink\x12\x63\n\x11posix_data_source\x18\x08 \x01(\x0b\x32H.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXPosixDataSource\x12\x62\n\x10transfer_options\x18\t \x01(\x0b\x32H.oak9.tython.gcp.storage.StorageTransferJobXTransferSpecXTransferOptions\"\x84\x03\n\x12StorageTransferJob\x12\x15\n\rcreation_time\x18\x01 \x01(\t\x12\x15\n\rdeletion_time\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x1e\n\x16last_modification_time\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0e\n\x06status\x18\x08 \x01(\t\x12\x46\n\x08schedule\x18\t \x01(\x0b\x32\x34.oak9.tython.gcp.storage.StorageTransferJobXSchedule\x12O\n\rtransfer_spec\x18\n \x01(\x0b\x32\x38.oak9.tython.gcp.storage.StorageTransferJobXTransferSpec\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_storage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STORAGEBUCKET_LABELSENTRY._options = None
  _STORAGEBUCKET_LABELSENTRY._serialized_options = b'8\001'
  _STORAGEBUCKETOBJECT_METADATAENTRY._options = None
  _STORAGEBUCKETOBJECT_METADATAENTRY._serialized_options = b'8\001'
  _STORAGEDEFAULTOBJECTACCESSCONTROL_PROJECTTEAMENTRY._options = None
  _STORAGEDEFAULTOBJECTACCESSCONTROL_PROJECTTEAMENTRY._serialized_options = b'8\001'
  _STORAGENOTIFICATION_CUSTOMATTRIBUTESENTRY._options = None
  _STORAGENOTIFICATION_CUSTOMATTRIBUTESENTRY._serialized_options = b'8\001'
  _STORAGEOBJECTACCESSCONTROL_PROJECTTEAMENTRY._options = None
  _STORAGEOBJECTACCESSCONTROL_PROJECTTEAMENTRY._serialized_options = b'8\001'
  _STORAGEBUCKETXCORS._serialized_start=71
  _STORAGEBUCKETXCORS._serialized_end=173
  _STORAGEBUCKETXENCRYPTION._serialized_start=175
  _STORAGEBUCKETXENCRYPTION._serialized_end=231
  _STORAGEBUCKETXLIFECYCLERULEXACTION._serialized_start=233
  _STORAGEBUCKETXLIFECYCLERULEXACTION._serialized_end=306
  _STORAGEBUCKETXLIFECYCLERULEXCONDITION._serialized_start=309
  _STORAGEBUCKETXLIFECYCLERULEXCONDITION._serialized_end=640
  _STORAGEBUCKETXLIFECYCLERULE._serialized_start=643
  _STORAGEBUCKETXLIFECYCLERULE._serialized_end=832
  _STORAGEBUCKETXLOGGING._serialized_start=834
  _STORAGEBUCKETXLOGGING._serialized_end=904
  _STORAGEBUCKETXRETENTIONPOLICY._serialized_start=906
  _STORAGEBUCKETXRETENTIONPOLICY._serialized_end=982
  _STORAGEBUCKETXTIMEOUTS._serialized_start=984
  _STORAGEBUCKETXTIMEOUTS._serialized_end=1054
  _STORAGEBUCKETXVERSIONING._serialized_start=1056
  _STORAGEBUCKETXVERSIONING._serialized_end=1099
  _STORAGEBUCKETXWEBSITE._serialized_start=1101
  _STORAGEBUCKETXWEBSITE._serialized_end=1174
  _STORAGEBUCKET._serialized_start=1177
  _STORAGEBUCKET._serialized_end=2156
  _STORAGEBUCKET_LABELSENTRY._serialized_start=2111
  _STORAGEBUCKET_LABELSENTRY._serialized_end=2156
  _STORAGEBUCKETACCESSCONTROLXTIMEOUTS._serialized_start=2158
  _STORAGEBUCKETACCESSCONTROLXTIMEOUTS._serialized_end=2243
  _STORAGEBUCKETACCESSCONTROL._serialized_start=2246
  _STORAGEBUCKETACCESSCONTROL._serialized_end=2500
  _STORAGEBUCKETACL._serialized_start=2503
  _STORAGEBUCKETACL._serialized_end=2672
  _STORAGEBUCKETIAMBINDINGXCONDITION._serialized_start=2674
  _STORAGEBUCKETIAMBINDINGXCONDITION._serialized_end=2765
  _STORAGEBUCKETIAMBINDING._serialized_start=2768
  _STORAGEBUCKETIAMBINDING._serialized_end=3002
  _STORAGEBUCKETIAMMEMBERXCONDITION._serialized_start=3004
  _STORAGEBUCKETIAMMEMBERXCONDITION._serialized_end=3094
  _STORAGEBUCKETIAMMEMBER._serialized_start=3097
  _STORAGEBUCKETIAMMEMBER._serialized_end=3328
  _STORAGEBUCKETIAMPOLICY._serialized_start=3331
  _STORAGEBUCKETIAMPOLICY._serialized_end=3475
  _STORAGEBUCKETOBJECTXCUSTOMERENCRYPTION._serialized_start=3477
  _STORAGEBUCKETOBJECTXCUSTOMERENCRYPTION._serialized_end=3571
  _STORAGEBUCKETOBJECTXTIMEOUTS._serialized_start=3573
  _STORAGEBUCKETOBJECTXTIMEOUTS._serialized_end=3651
  _STORAGEBUCKETOBJECT._serialized_start=3654
  _STORAGEBUCKETOBJECT._serialized_end=4439
  _STORAGEBUCKETOBJECT_METADATAENTRY._serialized_start=4392
  _STORAGEBUCKETOBJECT_METADATAENTRY._serialized_end=4439
  _STORAGEDEFAULTOBJECTACCESSCONTROLXTIMEOUTS._serialized_start=4441
  _STORAGEDEFAULTOBJECTACCESSCONTROLXTIMEOUTS._serialized_end=4533
  _STORAGEDEFAULTOBJECTACCESSCONTROL._serialized_start=4536
  _STORAGEDEFAULTOBJECTACCESSCONTROL._serialized_end=5010
  _STORAGEDEFAULTOBJECTACCESSCONTROL_PROJECTTEAMENTRY._serialized_start=4960
  _STORAGEDEFAULTOBJECTACCESSCONTROL_PROJECTTEAMENTRY._serialized_end=5010
  _STORAGEDEFAULTOBJECTACL._serialized_start=5013
  _STORAGEDEFAULTOBJECTACL._serialized_end=5144
  _STORAGEHMACKEYXTIMEOUTS._serialized_start=5146
  _STORAGEHMACKEYXTIMEOUTS._serialized_end=5219
  _STORAGEHMACKEY._serialized_start=5222
  _STORAGEHMACKEY._serialized_end=5512
  _STORAGENOTIFICATION._serialized_start=5515
  _STORAGENOTIFICATION._serialized_end=5905
  _STORAGENOTIFICATION_CUSTOMATTRIBUTESENTRY._serialized_start=5850
  _STORAGENOTIFICATION_CUSTOMATTRIBUTESENTRY._serialized_end=5905
  _STORAGEOBJECTACCESSCONTROLXTIMEOUTS._serialized_start=5907
  _STORAGEOBJECTACCESSCONTROLXTIMEOUTS._serialized_end=5992
  _STORAGEOBJECTACCESSCONTROL._serialized_start=5995
  _STORAGEOBJECTACCESSCONTROL._serialized_end=6448
  _STORAGEOBJECTACCESSCONTROL_PROJECTTEAMENTRY._serialized_start=4960
  _STORAGEOBJECTACCESSCONTROL_PROJECTTEAMENTRY._serialized_end=5010
  _STORAGEOBJECTACL._serialized_start=6451
  _STORAGEOBJECTACL._serialized_end=6615
  _STORAGETRANSFERJOBXSCHEDULEXSCHEDULEENDDATE._serialized_start=6617
  _STORAGETRANSFERJOBXSCHEDULEXSCHEDULEENDDATE._serialized_end=6704
  _STORAGETRANSFERJOBXSCHEDULEXSCHEDULESTARTDATE._serialized_start=6706
  _STORAGETRANSFERJOBXSCHEDULEXSCHEDULESTARTDATE._serialized_end=6795
  _STORAGETRANSFERJOBXSCHEDULEXSTARTTIMEOFDAY._serialized_start=6797
  _STORAGETRANSFERJOBXSCHEDULEXSTARTTIMEOFDAY._serialized_end=6905
  _STORAGETRANSFERJOBXSCHEDULE._serialized_start=6908
  _STORAGETRANSFERJOBXSCHEDULE._serialized_end=7256
  _STORAGETRANSFERJOBXTRANSFERSPECXAWSS3DATASOURCEXAWSACCESSKEY._serialized_start=7258
  _STORAGETRANSFERJOBXTRANSFERSPECXAWSS3DATASOURCEXAWSACCESSKEY._serialized_end=7370
  _STORAGETRANSFERJOBXTRANSFERSPECXAWSS3DATASOURCE._serialized_start=7373
  _STORAGETRANSFERJOBXTRANSFERSPECXAWSS3DATASOURCE._serialized_end=7572
  _STORAGETRANSFERJOBXTRANSFERSPECXAZUREBLOBSTORAGEDATASOURCEXAZURECREDENTIALS._serialized_start=7574
  _STORAGETRANSFERJOBXTRANSFERSPECXAZUREBLOBSTORAGEDATASOURCEXAZURECREDENTIALS._serialized_end=7670
  _STORAGETRANSFERJOBXTRANSFERSPECXAZUREBLOBSTORAGEDATASOURCE._serialized_start=7673
  _STORAGETRANSFERJOBXTRANSFERSPECXAZUREBLOBSTORAGEDATASOURCE._serialized_end=7920
  _STORAGETRANSFERJOBXTRANSFERSPECXGCSDATASINK._serialized_start=7922
  _STORAGETRANSFERJOBXTRANSFERSPECXGCSDATASINK._serialized_end=8002
  _STORAGETRANSFERJOBXTRANSFERSPECXGCSDATASOURCE._serialized_start=8004
  _STORAGETRANSFERJOBXTRANSFERSPECXGCSDATASOURCE._serialized_end=8086
  _STORAGETRANSFERJOBXTRANSFERSPECXHTTPDATASOURCE._serialized_start=8088
  _STORAGETRANSFERJOBXTRANSFERSPECXHTTPDATASOURCE._serialized_end=8154
  _STORAGETRANSFERJOBXTRANSFERSPECXOBJECTCONDITIONS._serialized_start=8157
  _STORAGETRANSFERJOBXTRANSFERSPECXOBJECTCONDITIONS._serialized_end=8359
  _STORAGETRANSFERJOBXTRANSFERSPECXPOSIXDATASINK._serialized_start=8361
  _STORAGETRANSFERJOBXTRANSFERSPECXPOSIXDATASINK._serialized_end=8432
  _STORAGETRANSFERJOBXTRANSFERSPECXPOSIXDATASOURCE._serialized_start=8434
  _STORAGETRANSFERJOBXTRANSFERSPECXPOSIXDATASOURCE._serialized_end=8507
  _STORAGETRANSFERJOBXTRANSFERSPECXTRANSFEROPTIONS._serialized_start=8510
  _STORAGETRANSFERJOBXTRANSFERSPECXTRANSFEROPTIONS._serialized_end=8701
  _STORAGETRANSFERJOBXTRANSFERSPEC._serialized_start=8704
  _STORAGETRANSFERJOBXTRANSFERSPEC._serialized_end=9653
  _STORAGETRANSFERJOB._serialized_start=9656
  _STORAGETRANSFERJOB._serialized_end=10044
# @@protoc_insertion_point(module_scope)
